#!/usr/bin/env python3

"""Default stylesheet data and processing for dragonglass."""

from pathlib import Path
from jinja2 import Environment

"""Name of the default stylesheet."""
STYLESHEET_NAME = "dragonglass.css"

"""Template data for the default stylesheet."""
STYLESHEET_DATA = """/* Dragonglass default CSS file - ensure all generated HTML pages reference this */
a {
    color: #8a5cf5;     
}
.invalid-reference {
    color: #ad8df8;
    text-decoration: underline;
    text-decoration-color: #e6ddfd;
}
ins {
    background-color: #ffec99;
    text-decoration: none;
}
blockquote {
    margin-left: 0px;
    padding-left: 0.5em;
    margin-right: 1em;
    border-left: 2px solid #9873f7;
}
span.task-list-item-checked {
    text-decoration-line: line-through;
}
div.codehilite {
    padding: 0.1em 0.25em;
    margin-top: 0.5em;
    margin-bottom: 0.5em;
}
table {
    border: 1px;
    border-collapse: collapse;
    border-spacing: 2px;
    line-height: 1.3;
    margin-top: 0.5em;
    margin-bottom: 0.5em;
}
td {
    border: 1px solid #e0e0e0;
}
th {
    border: 1px solid #e0e0e0;
}
.callout {
    --callout-color: 8, 109, 221;
    display: block;
    overflow: hidden;
    border-style: solid;
    border-color: rgba(var(--callout-color), 0.25);
    border-width: 0px;
    border-radius: 4px;
    margin: 1em 0;
    mix-blend-mode: darken;
    background-color: rgba(var(--callout-color), 0.1);
    padding: 12px 12px 12px 24px;
}
.callout[data-callout="example"] {
    --callout-color: 120, 82, 238;
}
.callout[data-callout="question"], .callout[data-callout="help"], .callout[data-callout="faq"] {
    --callout-color: 236, 117, 0;
}
.callout[data-callout="info"] {
    --callout-color: 8, 109, 221;
}
.callout[data-callout="tip"] {
    --callout-color: 0, 191, 188;
}
.callout[data-callout="todo"] {
    --callout-color: 8, 109, 221;
}
.callout-title {
    padding: 0;
    display: flex;
    gap: 4px;
    font-size: inherit;
    color: rgb(var(--callout-color));
    line-height: 1.3;
    align-items: flex-start;
}
.callout-icon {
    flex: 0 0 auto;
    display: flex;
    align-items: center;
}
.callout-title-inner {
    font-weight: 600;
    color: inherit;
}
.callout-content {
    margin-top: 1em;
    overflow-x: auto;
    padding: 0;
    background-color: transparent;
}
.lucide {
    width: 1em;
    height: 1em;
}

/* Following are styles generated by Pygments "tango" style */
pre { line-height: 125%; }
td.linenos .normal { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
span.linenos { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
td.linenos .special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
span.linenos.special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
.codehilite .hll { background-color: #ffffcc }
.codehilite { background: #f8f8f8; }
.codehilite .c { color: #8f5902; font-style: italic } /* Comment */
.codehilite .err { color: #a40000; border: 1px solid #ef2929 } /* Error */
.codehilite .g { color: #000000 } /* Generic */
.codehilite .k { color: #204a87; font-weight: bold } /* Keyword */
.codehilite .l { color: #000000 } /* Literal */
.codehilite .n { color: #000000 } /* Name */
.codehilite .o { color: #ce5c00; font-weight: bold } /* Operator */
.codehilite .x { color: #000000 } /* Other */
.codehilite .p { color: #000000; font-weight: bold } /* Punctuation */
.codehilite .ch { color: #8f5902; font-style: italic } /* Comment.Hashbang */
.codehilite .cm { color: #8f5902; font-style: italic } /* Comment.Multiline */
.codehilite .cp { color: #8f5902; font-style: italic } /* Comment.Preproc */
.codehilite .cpf { color: #8f5902; font-style: italic } /* Comment.PreprocFile */
.codehilite .c1 { color: #8f5902; font-style: italic } /* Comment.Single */
.codehilite .cs { color: #8f5902; font-style: italic } /* Comment.Special */
.codehilite .gd { color: #a40000 } /* Generic.Deleted */
.codehilite .ge { color: #000000; font-style: italic } /* Generic.Emph */
.codehilite .gr { color: #ef2929 } /* Generic.Error */
.codehilite .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite .gi { color: #00A000 } /* Generic.Inserted */
.codehilite .go { color: #000000; font-style: italic } /* Generic.Output */
.codehilite .gp { color: #8f5902 } /* Generic.Prompt */
.codehilite .gs { color: #000000; font-weight: bold } /* Generic.Strong */
.codehilite .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite .gt { color: #a40000; font-weight: bold } /* Generic.Traceback */
.codehilite .kc { color: #204a87; font-weight: bold } /* Keyword.Constant */
.codehilite .kd { color: #204a87; font-weight: bold } /* Keyword.Declaration */
.codehilite .kn { color: #204a87; font-weight: bold } /* Keyword.Namespace */
.codehilite .kp { color: #204a87; font-weight: bold } /* Keyword.Pseudo */
.codehilite .kr { color: #204a87; font-weight: bold } /* Keyword.Reserved */
.codehilite .kt { color: #204a87; font-weight: bold } /* Keyword.Type */
.codehilite .ld { color: #000000 } /* Literal.Date */
.codehilite .m { color: #0000cf; font-weight: bold } /* Literal.Number */
.codehilite .s { color: #4e9a06 } /* Literal.String */
.codehilite .na { color: #c4a000 } /* Name.Attribute */
.codehilite .nb { color: #204a87 } /* Name.Builtin */
.codehilite .nc { color: #000000 } /* Name.Class */
.codehilite .no { color: #000000 } /* Name.Constant */
.codehilite .nd { color: #5c35cc; font-weight: bold } /* Name.Decorator */
.codehilite .ni { color: #ce5c00 } /* Name.Entity */
.codehilite .ne { color: #cc0000; font-weight: bold } /* Name.Exception */
.codehilite .nf { color: #000000 } /* Name.Function */
.codehilite .nl { color: #f57900 } /* Name.Label */
.codehilite .nn { color: #000000 } /* Name.Namespace */
.codehilite .nx { color: #000000 } /* Name.Other */
.codehilite .py { color: #000000 } /* Name.Property */
.codehilite .nt { color: #204a87; font-weight: bold } /* Name.Tag */
.codehilite .nv { color: #000000 } /* Name.Variable */
.codehilite .ow { color: #204a87; font-weight: bold } /* Operator.Word */
.codehilite .w { color: #f8f8f8 } /* Text.Whitespace */
.codehilite .mb { color: #0000cf; font-weight: bold } /* Literal.Number.Bin */
.codehilite .mf { color: #0000cf; font-weight: bold } /* Literal.Number.Float */
.codehilite .mh { color: #0000cf; font-weight: bold } /* Literal.Number.Hex */
.codehilite .mi { color: #0000cf; font-weight: bold } /* Literal.Number.Integer */
.codehilite .mo { color: #0000cf; font-weight: bold } /* Literal.Number.Oct */
.codehilite .sa { color: #4e9a06 } /* Literal.String.Affix */
.codehilite .sb { color: #4e9a06 } /* Literal.String.Backtick */
.codehilite .sc { color: #4e9a06 } /* Literal.String.Char */
.codehilite .dl { color: #4e9a06 } /* Literal.String.Delimiter */
.codehilite .sd { color: #8f5902; font-style: italic } /* Literal.String.Doc */
.codehilite .s2 { color: #4e9a06 } /* Literal.String.Double */
.codehilite .se { color: #4e9a06 } /* Literal.String.Escape */
.codehilite .sh { color: #4e9a06 } /* Literal.String.Heredoc */
.codehilite .si { color: #4e9a06 } /* Literal.String.Interpol */
.codehilite .sx { color: #4e9a06 } /* Literal.String.Other */
.codehilite .sr { color: #4e9a06 } /* Literal.String.Regex */
.codehilite .s1 { color: #4e9a06 } /* Literal.String.Single */
.codehilite .ss { color: #4e9a06 } /* Literal.String.Symbol */
.codehilite .bp { color: #3465a4 } /* Name.Builtin.Pseudo */
.codehilite .fm { color: #000000 } /* Name.Function.Magic */
.codehilite .vc { color: #000000 } /* Name.Variable.Class */
.codehilite .vg { color: #000000 } /* Name.Variable.Global */
.codehilite .vi { color: #000000 } /* Name.Variable.Instance */
.codehilite .vm { color: #000000 } /* Name.Variable.Magic */
.codehilite .il { color: #0000cf; font-weight: bold } /* Literal.Number.Integer.Long */
"""


def write_default_stylesheet(tenv: Environment, dest_dir: Path) -> None:
    """
    Writes the default stylesheet data to the destination directory.

    Args:
        tenv (Environment): Template engine used to render the default stylesheet data.
        dest_dir (Path): The destination directory to write the stylesheet to.
    """
    to_file = dest_dir / STYLESHEET_NAME
    tmpl = tenv.from_string(STYLESHEET_DATA)
    data = tmpl.render({})
    with to_file.open("wt") as f:
        f.write(data)
